summaryrefslogtreecommitdiffstats
path: root/src/projectsession.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/projectsession.cpp')
-rw-r--r--src/projectsession.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/projectsession.cpp b/src/projectsession.cpp
index 2676f56b..f09967ef 100644
--- a/src/projectsession.cpp
+++ b/src/projectsession.cpp
@@ -3,7 +3,7 @@
-------------------
begin : 30 Nov 2002
copyright : (C) 2002 by Falk Brettschneider
- email : falk@kdevelop.org
+ email : falk@tdevelop.org
***************************************************************************/
/***************************************************************************
@@ -52,7 +52,7 @@ ProjectSession::~ProjectSession()
//---------------------------------------------------------------------------
void ProjectSession::initXMLTree()
{
// initializes the XML tree on startup of kdevelop and when a project
// has been closed to ensure that the XML tree exists already including
// doctype when a project gets opened that doesn't have a kdevses file
// or a new project gets generated (which doesn't have a kdevses file
@@ -52,7 +52,7 @@ ProjectSession::~ProjectSession()
void ProjectSession::initXMLTree()
{
- // initializes the XML tree on startup of kdevelop and when a project
+ // initializes the XML tree on startup of tdevelop and when a project
// has been closed to ensure that the XML tree exists already including
// doctype when a project gets opened that doesn't have a kdevses file